summaryrefslogtreecommitdiff
path: root/include/user/usbstorvstor.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/user/usbstorvstor.h')
-rw-r--r--include/user/usbstorvstor.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/user/usbstorvstor.h b/include/user/usbstorvstor.h
index c71eb66..664133b 100644
--- a/include/user/usbstorvstor.h
+++ b/include/user/usbstorvstor.h
@@ -5,10 +5,10 @@
extern "C" {
#endif
-enum {
- SCE_USBSTOR_VSTOR_TYPE_FAT = 0,
- SCE_USBSTOR_VSTOR_TYPE_CDROM = 5,
-};
+typedef enum SceUsbstorVstorType {
+ SCE_USBSTOR_VSTOR_TYPE_FAT = 0,
+ SCE_USBSTOR_VSTOR_TYPE_CDROM = 5
+} SceUsbstorVstorType;
/**
* Set image file path
@@ -32,11 +32,11 @@ int sceUsbstorVStorSetDeviceInfo(const char *name, const char *version);
/**
* Start USB virtual storage
*
* @param[in] type - One of ::UsbStorVstorType
*
* @return 0 on success, < 0 on error.
*/
-int sceUsbstorVStorStart(int type);
+int sceUsbstorVStorStart(SceUsbStorVstorType type);
/**
* Stop USB virtual storage
@@ -32,11 +32,11 @@ int sceUsbstorVStorSetDeviceInfo(const char *name, const char *version);
* Start USB virtual storage
*
- * @param[in] type - One of ::UsbStorVstorType
+ * @param[in] type - One of ::SceUsbStorVstorType
*
* @return 0 on success, < 0 on error.